<?php

/**
* The dashboard-specific functionality of the plugin.
*
* @link 		https://lin3s.com
* @since 		1.0.0
*
* @package 		Alexandria_Conversation_Builder
* @subpackage 	Alexandria_Conversation_Builder/admin
*/

class Alexandria_Conversation_Builder_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$plugin_name 		The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since 		1.0.0
	 * @access 		private
	 * @var 		string 			$version 			The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since 		1.0.0
	 * @param 		string 			$plugin_name 			The name of this plugin.
	 * @param 		string 			$version 				The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

		define( 'ALEXANDRIA_CONVERSATION_BUILDER_ADMIN_PATH', plugin_dir_url( __FILE__ ));

	}

	/**
     * Adds notices for the admin to display.
     * Saves them in a temporary plugin option.
     * This method is called on plugin activation, so its needs to be static.
     */
	public static function add_admin_notices() {

		$notices = get_option( 'alexandria_conversation_builder_deferred_admin_notices', array() );

		apply_filters( 'alexandria_conversation_builder_admin_notices', $notices );
		update_option( 'alexandria_conversation_builder_deferred_admin_notices', $notices );

    } // add_admin_notices

	/**
	 * Adds a settings page link to a menu
	 *
	 * @link 		https://codex.wordpress.org/Administration_Menus
	 * @since 		1.0.0
	 * @return 		void
	 */
	public function add_menu() {

		$alexandria_caps = current_user_can('manage_options') ? 'manage_options' : 'alexandria_manage';

		// Top-level page
		// add_menu_page( $page_title, $menu_title, $capability, $menu_slug, $function, $icon_url, $position );

		// Submenu Page
		// add_submenu_page( $parent_slug, $page_title, $menu_title, $capability, $menu_slug, $function);

		add_menu_page(
			esc_html__('Buider de Conversaciones', 'alexandria-conversation-builder'),
			esc_html__('Buider de Conversaciones', 'alexandria-conversation-builder'),
			$alexandria_caps,
			$this->plugin_name . '-admin-menu',
			array( $this, 'page_landing' ),
			'dashicons-hammer'
		);

		add_submenu_page(
			$this->plugin_name . '-admin-menu',
			apply_filters( $this->plugin_name . '-conversations-list-page-title', esc_html__( 'Conversaciones', 'alexandria-conversation-builder' ) ),
			apply_filters( $this->plugin_name . '-conversations-list-menu-title', esc_html__( 'Conversaciones', 'alexandria-conversation-builder' ) ),
			$alexandria_caps,
			'/edit.php?post_type=conversations'
		);

		add_submenu_page(
			$this->plugin_name . '-admin-menu',
			apply_filters( $this->plugin_name . '-interlocutores-list-page-title', esc_html__( 'Interlocutores', 'alexandria-conversation-builder' ) ),
			apply_filters( $this->plugin_name . '-interlocutores-list-menu-title', esc_html__( 'Interlocutores', 'alexandria-conversation-builder' ) ),
			$alexandria_caps,
			'/edit.php?post_type=interlocutors'
		);

		add_submenu_page(
			$this->plugin_name . '-admin-menu',
			apply_filters( $this->plugin_name . '-situations-list-page-title', esc_html__( 'Situaciones', 'alexandria-conversation-builder' ) ),
			apply_filters( $this->plugin_name . '-situations-list-menu-title', esc_html__( 'Situaciones', 'alexandria-conversation-builder' ) ),
			$alexandria_caps,
			'/edit.php?post_type=situations'
		);

		add_submenu_page(
			$this->plugin_name . '-admin-menu',
			apply_filters( $this->plugin_name . '-situations-list-page-title', esc_html__( 'Tipos de Situaciones', 'alexandria-conversation-builder' )),
			apply_filters( $this->plugin_name . '-situations-list-menu-title', esc_html__( 'Tipos de Situaciones', 'alexandria-conversation-builder' )),
			$alexandria_caps,
			'/edit-tags.php?taxonomy=situations-categories'
		);

		add_submenu_page(
			$this->plugin_name . '-admin-menu',
			apply_filters( $this->plugin_name . '-tonos-list-page-title', esc_html__( 'Tonos', 'alexandria-conversation-builder' ) ),
			apply_filters( $this->plugin_name . '-tonos-list-menu-title', esc_html__( 'Tonos', 'alexandria-conversation-builder' ) ),
			$alexandria_caps,
			'/edit.php?post_type=tonos'
		);

		add_menu_page(
			esc_html__('Builder de Conversaciones - Output', 'alexandria-conversation-builder'),
			esc_html__('Builder de Conversaciones - Output', 'alexandria-conversation-builder'),
			$alexandria_caps,
			$this->plugin_name . '-second-menu',
			array( $this, 'page_landing_elements' ),
			'dashicons-clipboard'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-objectives-list-page-title', esc_html__( 'Objetivos', 'alexandria-conversation-builder' ) ),
			apply_filters( $this->plugin_name . '-objectives-list-menu-title', esc_html__( 'Objetivos', 'alexandria-conversation-builder' ) ),
			$alexandria_caps,
			'/edit.php?post_type=objectives'
		);	

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-soliloquios-list-page-title', esc_html__( 'Soliloquios', 'alexandria-conversation-builder' ) ),
			apply_filters( $this->plugin_name . '-soliloquios-list-menu-title', esc_html__( 'Soliloquios', 'alexandria-conversation-builder' ) ),
			$alexandria_caps,
			'/edit.php?post_type=soliloquios'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-conclusions-list-page-title', esc_html__( 'Listado de Conclusiones', 'alexandria-conversation-builder' )),
			apply_filters( $this->plugin_name . '-conclusions-list-menu-title', esc_html__( 'Conclusiones', 'alexandria-conversation-builder' )),
			$alexandria_caps,
			'/edit.php?post_type=conclusions'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-decisions-list-page-title', esc_html__( 'Decisiones', 'alexandria-conversation-builder' ) ),
			apply_filters( $this->plugin_name . '-decisions-list-menu-title', esc_html__( 'Decisiones', 'alexandria-conversation-builder' ) ),
			$alexandria_caps,
			'/edit.php?post_type=decisions'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-results-page-title', esc_html__( 'Resultados Esperados', 'alexandria-conversation-builder' ) ),
			apply_filters( $this->plugin_name . '-results-menu-title', esc_html__( 'Resultados Esperados', 'alexandria-conversation-builder' ) ),
			$alexandria_caps,
			'/edit.php?post_type=expect_results'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-strong-questions-page-title', esc_html__( 'Preguntas Potentes', 'alexandria-conversation-builder' ) ),
			apply_filters( $this->plugin_name . '-strong-questions-menu-title', esc_html__( 'Preguntas Potentes', 'alexandria-conversation-builder' ) ),
			$alexandria_caps,
			'/edit.php?post_type=strong_questions'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-strong-questions-categories-page-title', esc_html__( 'Categorías Preguntas Potentes', 'alexandria-conversation-builder' ) ),
			apply_filters( $this->plugin_name . '-strong-questions-categories-menu-title', esc_html__( 'Categorías Preguntas Potentes', 'alexandria-conversation-builder' ) ),
			$alexandria_caps,
			'/edit-tags.php?taxonomy=strong_questions-categories'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-relevances-page-title', esc_html__( 'Relevancias', 'alexandria-conversation-builder' ) ),
			apply_filters( $this->plugin_name . '-relevances-menu-title', esc_html__( 'Relevancias', 'alexandria-conversation-builder' ) ),
			$alexandria_caps,
			'/edit.php?post_type=relevances'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-arguments-list-page-title', esc_html__( 'Argumentos', 'alexandria-conversation-builder' ) ),
			apply_filters( $this->plugin_name . '-arguments-list-menu-title', esc_html__( 'Argumentos', 'alexandria-conversation-builder' ) ),
			$alexandria_caps,
			'/edit.php?post_type=arguments'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-viable_minimal-list-page-title', esc_html__( 'Mínimo Viable', 'alexandria-conversation-builder' ) ),
			apply_filters( $this->plugin_name . '-viable_minimal-list-menu-title', esc_html__( 'Mínimo Viable', 'alexandria-conversation-builder' ) ),
			$alexandria_caps,
			'/edit.php?post_type=viable_minimal'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-alexandria-comments-list-page-title', esc_html__( 'Comentarios', 'alexandria-conversation-builder' ) ),
			apply_filters( $this->plugin_name . '-alexandria-comments-list-menu-title', esc_html__( 'Comentarios', 'alexandria-conversation-builder' ) ),
			$alexandria_caps,
			'/edit.php?post_type=alexandria_comments'
		);

		add_submenu_page(
			$this->plugin_name . '-second-menu',
			apply_filters( $this->plugin_name . '-alexandria-examples-list-page-title', esc_html__( 'Ejemplos', 'alexandria-conversation-builder' ) ),
			apply_filters( $this->plugin_name . '-alexandria-examples-list-menu-title', esc_html__( 'Ejemplos', 'alexandria-conversation-builder' ) ),
			$alexandria_caps,
			'/edit.php?post_type=builder_examples'
		);

		add_menu_page(
			esc_html__('Builder de Conversaciones - Configuración', 'alexandria-conversation-builder'),
			esc_html__('Builder de Conversaciones - Configuración', 'alexandria-conversation-builder'),
			$alexandria_caps,
			$this->plugin_name . '-config-menu',
			array( $this, 'page_options' ),
			'dashicons-admin-generic'
		);

		add_submenu_page(
			$this->plugin_name . '-config-menu',
			apply_filters( $this->plugin_name . '-settings-page-title', esc_html__( 'Configuración', 'alexandria-conversation-builder' ) ),
			apply_filters( $this->plugin_name . '-settings-menu-title', esc_html__( 'Configuración', 'alexandria-conversation-builder' ) ),
			$alexandria_caps,
			$this->plugin_name . '-settings',
			array( $this, 'page_options' )
		);

		add_submenu_page(
			$this->plugin_name . '-config-menu',
			apply_filters( $this->plugin_name . '-objectives-builder-page-title', esc_html__( 'Objetivos Página Principal', 'alexandria-conversation-builder' ) ),
			apply_filters( $this->plugin_name . '-objectives-builder-menu-title', esc_html__( 'Objetivos Página Principal', 'alexandria-conversation-builder' ) ),
			$alexandria_caps,
			'/edit.php?post_type=objectives_builder'
		);

		add_submenu_page(
			$this->plugin_name . '-config-menu',
			apply_filters( $this->plugin_name . '-help-page-title', esc_html__( 'Ayuda', 'alexandria-conversation-builder' ) ),
			apply_filters( $this->plugin_name . '-help-menu-title', esc_html__( 'Ayuda', 'alexandria-conversation-builder' ) ),
			$alexandria_caps,
			$this->plugin_name . '-help',
			array( $this, 'page_help' )
		);

	} // add_menu()

	/**
     * Manages any updates or upgrades needed before displaying notices.
     * Checks plugin version against version required for displaying
     * notices.
     */
	public function admin_notices_init() {

		$current_version = '1.0.0';

		if ( $this->version !== $current_version ) {

			// Do whatever upgrades needed here.

			update_option('1.0.0', $current_version);

			$this->add_notice();
		}

	} // admin_notices_init()

	/**
     * Manages any updates or upgrades needed before displaying notices.
     * Checks plugin version against version required for displaying
     * notices.
     */
	public function db_init() {

		add_action('init', array("AlexandriaConversationBuilder", "init"));

	} // db_init()

	/**
	 * Highlight Menu
	 *
	 * @return 	string 			Admin notices
	 */
	function menu_highlight( $parent_file ) {
		global $current_screen;

		$taxonomy = $current_screen->taxonomy;
		if ( $taxonomy == 'strong_questions-categories' ) {
			$parent_file = 'strong_questions';
		}

		if ( $taxonomy == 'situations-categories' ) {
			$parent_file = 'situations';
		}

		if ( $taxonomy == 'petitions-categories' ) {
			$parent_file = 'petitions';
		}

		return $parent_file;
	}


	/**
	 * Displays admin notices
	 *
	 * @return 	string 			Admin notices
	 */
	public function display_admin_notices() {

		$notices = get_option( 'alexandria_conversation_builder_deferred_admin_notices' );

		if ( empty( $notices ) ) { return; }

		foreach ( $notices as $notice ) {

			echo '<div class="' . esc_attr( $notice['class'] ) . '"><p>' . $notice['notice'] . '</p></div>';

		}

		delete_option( 'alexandria_conversation_builder_deferred_admin_notices' );

    } // display_admin_notices()

	/**
	 * Register the stylesheets for the Dashboard.
	 *
	 * @since 		1.0.0
	 */
	public function enqueue_styles() {
		wp_enqueue_style( 'wp-color-picker' );
		wp_register_style( 'select2css', '//cdnjs.cloudflare.com/ajax/libs/select2/3.4.8/select2.css', false, '1.0', 'all' );
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/' . $this->plugin_name . '-admin.css', array(), $this->version, 'all' );

		wp_enqueue_style( 'select2css' );
		

	} // enqueue_styles()

	/**
	 * Register the JavaScript for the dashboard.
	 *
	 * @since 		1.0.0
	 */
	public function enqueue_scripts( $hook_suffix ) {
		wp_enqueue_script('jquery');
		wp_enqueue_script('jquery-ui-sortable');

		wp_register_script( 'select2', '//cdnjs.cloudflare.com/ajax/libs/select2/3.4.8/select2.js', array( 'jquery' ), '1.0', true );
		
		wp_register_script( $this->plugin_name.'-dual-box', plugin_dir_url( __FILE__ ) . 'js/' . $this->plugin_name . '-dual-box.js', '1.0', true);
		wp_register_script( $this->plugin_name.'-order-list', plugin_dir_url( __FILE__ ) . 'js/' . $this->plugin_name . '-order-list.js', array('jquery'), '1.0', true);
		wp_register_script( $this->plugin_name.'-video-uploader', plugin_dir_url( __FILE__ ) . 'js/' . $this->plugin_name . '-video-uploader.js', array('jquery'), '1.0', true);
		wp_register_script( $this->plugin_name.'-main', plugin_dir_url( __FILE__ ) . 'js/' . $this->plugin_name . '-main.js', array('wp-color-picker', 'jquery'), '1.0', true);

		$translated_form_strings = array(
			'admin_url' => admin_url('admin-ajax.php'),

			'arguments_string' => __('Argumentos', 'alexandria-conversation-builder'),
			'soliloquios' => __('Soliloquios', 'alexandria-conversation-builder'),

			'examples_string' => __('Ejemplos', 'alexandria-conversation-builder'),
			'comments_string' => __('Comentarios', 'alexandria-conversation-builder'),

			'seleccionadas_string' => __('Seleccionadas', 'alexandria-conversation-builder'),
			'seleccionados_string' => __('Seleccionados', 'alexandria-conversation-builder'),

			'search_string' => __('Buscar', 'alexandria-conversation-builder'),

			'order_string' => __('Ordenar', 'alexandria-conversation-builder'),
			'ordering_string' => __('Ordenando', 'alexandria-conversation-builder'),
			'order_notice_string' => __('Estas ordenando el listado.', 'alexandria-conversation-builder')
		);

		wp_localize_script( $this->plugin_name.'-order-list', 'translated_strings', $translated_form_strings );
		wp_localize_script( $this->plugin_name.'-main', 'translated_strings', $translated_form_strings );

		wp_enqueue_script( 'select2' );
		wp_enqueue_script( $this->plugin_name.'-dual-box' );
		wp_enqueue_script( $this->plugin_name.'-order-list' );
		wp_enqueue_script( $this->plugin_name.'-video-uploader' );
		wp_enqueue_script( $this->plugin_name.'-main' );

	} // enqueue_scripts()
	

	/**
	 * Register Media
	 *
	 * @since 		1.0.0
	 */
	public function load_media_files() {
		wp_enqueue_media();
	} // enqueue_scripts()	add_action( 'admin_enqueue_scripts', 'load_media_files' );


	/**
	 * Adds links to the plugin links row
	 *
	 * @since 		1.0.0
	 * @param 		array 		$links 		The current array of row links
	 * @param 		string 		$file 		The name of the file
	 * @return 		array 					The modified array of row links
	 */
	public function link_row( $links, $file ) {

		if ( ALEXANDRIA_CONVERSATION_BUILDER_FILE === $file ) {
			$links[] = '<a href="https://lin3s.com">Lin3s Web</a>';
		}

		return $links;

	} // link_row()

	/**
	 * Adds a link to the plugin settings page
	 *
	 * @since 		1.0.0
	 * @param 		array 		$links 		The current array of links
	 * @return 		array 					The modified array of links
	 */
	public function link_settings( $links ) {

		$links[] = sprintf( '<a href="%s">%s</a>', esc_url( admin_url( 'admin.php?page=' . $this->plugin_name . '-settings' ) ), esc_html__( 'Configuración', 'alexandria-conversation-builder' ) );

		return $links;

	} // link_settings()

	/**
	 * Creates the landing page
	 *
	 * @since 		1.0.0
	 * @return 		void
	 */
	public function page_landing() {

		include( plugin_dir_path( __FILE__ ) . 'partials/' . $this->plugin_name . '-admin-landing.php' );

	} // page_landing()

	/**
	 * Creates the landing page elements
	 *
	 * @since 		1.0.0
	 * @return 		void
	 */
	public function page_landing_elements() {

		include( plugin_dir_path( __FILE__ ) . 'partials/' . $this->plugin_name . '-admin-landing-elements.php' );

	} // page_landing_elements()


	/**
	 * Creates the options page
	 *
	 * @since 		1.0.0
	 * @return 		void
	 */
	public function page_options() {

		include( plugin_dir_path( __FILE__ ) . 'partials/' . $this->plugin_name . '-admin-page-settings.php' );

	} // page_options()

	/**
	 * Creates the help page
	 *
	 * @since 		1.0.0
	 * @return 		void
	 */
	public function page_help() {

		include( plugin_dir_path( __FILE__ ) . 'partials/' . $this->plugin_name . '-admin-page-help.php' );

	} // page_help()

	/**
	 * Disable Gutengber in certain post types
	 *
	 * @since 		1.0.0
	 * @return 		file
	 */
	public function alexandria_disable_gutenberg( $is_enabled, $post_type ) {
		if ($post_type === 'objectives') return false;
		if ($post_type === 'objectives_builder') return false;
		if ($post_type === 'builder_examples') return false;
		if ($post_type === 'arguments') return false;
		return $is_enabled;
	}

	/**
	 * Registers settings fields with WordPress
	 */
	public function register_fields() {

		$plugin_settings = new Alexandria_Conversation_Builder_Settings_Fields( $this->plugin_name, $this->version );

		$plugin_settings->register_settings_sections();
		$plugin_settings->register_settings_fields();

	} // register_fields()

	

	/**
	* Registers plugin settings
	*
	* @since 		1.0.0
	* @return 		void
	*/
	public function register_settings() {

		$plugin_settings = new Alexandria_Conversation_Builder_Settings_Fields( $this->plugin_name, $this->version );
		
		$plugin_settings->register_settings();

	}// register_settings()

	/**
	 * Register horizontal scroll option
	 */
	public function register_screen_option($option, $args) {

		$option = 'horizontal_scroll';

		$args = array(
			'label' => __('Horizontal Scroll', 'entusiastics-quiz-game'),
			'default' => 5,
			'option' => 'horizontal_scroll'
		);

		add_screen_option( $option, $args );
	}

	private function is_windows_browser() {
		if ( ! isset( $_SERVER['HTTP_USER_AGENT'] ) ) {
			return false;
		}

		return (bool) preg_match( '(win|microsoft)', strtolower( $_SERVER['HTTP_USER_AGENT'] ) );
	}


} // class